@@ -1,5 +1,5 @@
-/*
- * ContactListView
+/* $Id: ContactListView.cpp,v 1.23 2001/12/19 12:28:55 barnabygray Exp $
+ * 
  * Copyright (C) 2001 Barnaby Gray <barnaby@beedesign.co.uk>.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,17 +20,21 @@
 
 #include "ContactListView.h"
 
+#include <gdk/gdkkeysyms.h>
 #include <vector>
 #include <string>
 #include <algorithm>
 #include <utility>
+#include "sstream_fix.h"
 
 #include "Client.h"
+#include "PromptDialog.h"
 
 using std::string;
 using std::vector;
 using std::transform;
 using std::inserter;
+using std::ostringstream;
 
 ContactListView::ContactListView()
   : CList(2) {
@@ -132,23 +136,27 @@ gint ContactListView::key_press_event_impl(GdkEventKey *ev) {
     row_iter = rows().begin();
   }
 
-  start_iter = row_iter;
-  ++row_iter;
-  if (row_iter == rows().end()) row_iter = rows().begin();
-
-  while (row_iter != start_iter) {
-    Row &row = *row_iter;
-    if (key == ((RowData *) row.get_data() )->alias[0]) {
-      row.select();
-      break;
-    }
+  if( ev->keyval == GDK_Return || ev->keyval== GDK_KP_Enter || ev->keyval== GDK_space ) {
+    user_popup.emit( ((RowData *) row_iter->get_data() )->uin );
+  }
+  else {
+    start_iter = row_iter;
     ++row_iter;
     if (row_iter == rows().end()) row_iter = rows().begin();
+
+    while (row_iter != start_iter) {
+      Row &row = *row_iter;
+      if (key == ((RowData *) row.get_data() )->alias[0]) {
+        row.select();
+        break;
+      }
+      ++row_iter;
+      if (row_iter == rows().end()) row_iter = rows().begin();
+    }
+
+    if (!row_is_visible((*row_iter).get_row_num()))
+      moveto( (*row_iter).get_row_num(), 0 );
   }
-
-  if (!row_is_visible((*row_iter).get_row_num()))
-    moveto( (*row_iter).get_row_num(), 0 );
-
   return Gtk::CList::key_press_event_impl(ev);
 }
 
@@ -157,10 +165,14 @@ void ContactListView::userinfo_cb() {
 }
 
 void ContactListView::remove_user_cb() {
-  Gtk::CList_Helpers::SelectionList sl = selection();
-  Row r = *(sl.begin());
-  RowData *p = (RowData*)(*r).get_data();
-  icqclient.removeContact(p->uin);
+  unsigned int uin = current_selection_uin();
+  Contact *c = icqclient.getContact(uin);
+  if (c != NULL) {
+    ostringstream ostr;
+    ostr << "Are you sure you want to remove " << c->getAlias() << " (" << uin << ")?";
+    PromptDialog p(PromptDialog::PROMPT_CONFIRM, ostr.str());
+    if (p.run()) icqclient.removeContact(uin);
+  }
 }
 
 void ContactListView::fetch_away_msg_cb() {
