@@ -1,5 +1,5 @@
-/*
- * Icons
+/* $Id: Icons.h,v 1.7 2001/12/18 22:16:52 barnabygray Exp $
+ *
  * Copyright (C) 2001 Barnaby Gray <barnaby@beedesign.co.uk>.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -35,7 +35,6 @@ using Gtk::ImageLoader;
 using Gtk::ImageLoaderData;
 using ICQ2000::MessageEvent;
 using std::string;
-using SigC::Signal0;
 
 class Icons {
  private:
@@ -58,7 +57,9 @@ class Icons {
   ImageLoader* IconForStatus(Status s,bool inv);
   ImageLoader* IconForEvent(MessageEvent::MessageType t);
 
-  Signal0<void> icons_changed;
+  void settings_changed_cb(const string& key);
+
+  SigC::Signal0<void> icons_changed;
 
 };
 
