@@ -1,4 +1,4 @@
-/* $Id: MessageBox.h,v 1.9 2001/12/12 22:43:00 nordman Exp $
+/* $Id: MessageBox.h,v 1.12 2001/12/24 13:58:38 barnabygray Exp $
  *
  * Copyright (C) 2001 Barnaby Gray <barnaby@beedesign.co.uk>.
  *
@@ -65,6 +65,7 @@ class MessageBox : public Gtk::Window {
 
   Gtk::Table m_history_table;
   Gtk::Text m_history_text;
+  guchar m_nr_shown;
 
   Gtk::Notebook m_tab;
 
@@ -91,11 +92,16 @@ class MessageBox : public Gtk::Window {
 
   MessageEvent::MessageType m_message_type;
 
+  SigC::Connection m_settingsconn;
+
+
   void send_button_update();
   void set_contact_title();
   string format_time(time_t t);
   void display_message(History::Entry &he);
   void set_status( const string& text );
+  void redraw_history();
+  guint update_scalelabel(guint i);
   void scaleadj_value_changed_cb();
   gint text_button_press_cb(GdkEventButton *b, Gtk::Text *t);
 
@@ -129,6 +135,8 @@ class MessageBox : public Gtk::Window {
   void switch_page_cb(Gtk::Notebook_Helpers::Page* p, guint n);
   void userinfo_toggle_cb();
   void sms_count_update_cb();
+  void icons_changed_cb();
+  void settings_changed_cb(const string &key);
   gint key_press_cb(GdkEventKey*);
   virtual gint delete_event_impl(GdkEventAny *ev);
 };
