@@ -1,5 +1,5 @@
-/*
- * Settings
+/* $Id: Settings.h,v 1.12 2001/12/21 17:57:40 nordman Exp $
+ * 
  * Handle loading/parsing/saving of settings to
  * a configuration file
  *
@@ -24,29 +24,16 @@
 #ifndef SETTINGS_H
 #define SETTINGS_H
 
-#include <string>
-
 #include <config.h>
-
-#ifdef HAVE_EXT_HASH_MAP
-# include <ext/hash_map>
-#elif HAVE_HASH_MAP
-# include <hash_map>
-#else
-# error "hash_map not defined"
-#endif
+#include <string>
+#include <map>
+#include <sigc++/signal_system.h>
 
 using std::string;
-using std::hash_map;
 
-class _HashString {
- public:
-  size_t operator()(string const &str) const { return std::hash<char const *>()(str.c_str()); }
-};
-  
-class Settings {
+class Settings : public SigC::Object {
  private:
-  hash_map<const string,string,_HashString> m_map;
+  std::map<const string,string> m_map;
   
  public:
   Settings();
@@ -81,6 +68,7 @@ class Settings {
   static string Escape(const string& t);
   static string Unescape(const string& t);
 
+  SigC::Signal1<void,const string &> settings_changed;
 };
 
 #endif
