@@ -1,5 +1,5 @@
-/*
- * SettingsDialog
+/* $Id: SettingsDialog.cpp,v 1.20 2001/12/18 22:16:52 barnabygray Exp $
+ *
  * Copyright (C) 2001 Barnaby Gray <barnaby@beedesign.co.uk>.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -488,11 +488,9 @@ void SettingsDialog::okay_cb() {
 void SettingsDialog::cancel_cb() {
   Gtk::Main::quit();
   finished_okay = false;
-  string m_old_icons_dir = g_settings.getValueString("icons_dir");
-  if ( getIconsFilename() != m_old_icons_dir ) {
-    // restore icons
-    g_icons.setIcons( m_old_icons_dir );
-  }
+
+  // restore icons
+  g_icons.setIcons( g_settings.getValueString("icons_dir") );
 }
 
 void SettingsDialog::trans_cb() {
