@@ -137,6 +137,7 @@ namespace ICQ2000 {
     void SignalDisconnect(DisconnectedEvent::Reason r);
     void SignalMessage(MessageSNAC *snac);
     void SignalMessageACK(MessageACKSNAC *snac);
+    void SignalMessageOfflineUser(MessageOfflineUserSNAC *snac);
     void SignalSrvResponse(SrvResponseSNAC *snac);
     void SignalUINResponse(UINResponseSNAC *snac);
     void SignalUINRequestError();
@@ -210,6 +211,9 @@ namespace ICQ2000 {
 
     bool SendDirect(MessageEvent *ev);
     void SendViaServer(MessageEvent *ev);
+    void SendViaServerAdvanced(MessageEvent *ev);
+    void SendViaServerNormal(MessageEvent *ev);
+    UINICQSubType* EventToUINICQSubType(MessageEvent *ev);
     
     void Connect();
     void Disconnect(DisconnectedEvent::Reason r = DisconnectedEvent::REQUESTED);
