@@ -82,6 +82,9 @@ namespace ICQ2000 {
       case TLV_Port:
 	tlv = new PortTLV();
 	break;
+      case TLV_Capabilities:
+	tlv = new CapabilitiesTLV();
+	break;
       }
       break;
 
@@ -227,9 +230,9 @@ namespace ICQ2000 {
 
   }
 
-  // ----------------- Capabilities TLV -----------
+  // ----------------- UserInfoCapabilities TLV -----------
 
-  void CapabilitiesTLV::OutputValue(Buffer& b) const {
+  void UserInfoCapabilitiesTLV::OutputValue(Buffer& b) const {
     b << Length();
     b << (unsigned int)0x09461349
       << (unsigned int)0x4c7f11d1
@@ -241,6 +244,24 @@ namespace ICQ2000 {
       << (unsigned int)0x53540000;
   }
 
+  // ----------------- Capabilities TLV -----------
+
+  void CapabilitiesTLV::ParseValue(Buffer& b) {
+    unsigned short l;
+    b >> l;
+
+    // ICQ2001 sends out 64 bytes or so
+    // ICQ2000 sends out 32 bytes
+    // ICQLite sends out 16, so this is what we'll use for now until someone
+    // figures out what those capabilities mean
+    if (l > 16)
+      m_accept_adv_msgs = true;
+    else
+      m_accept_adv_msgs = false;
+  }
+
+  bool CapabilitiesTLV::getAcceptAdvMsgs() const { return m_accept_adv_msgs; }
+
   // ----------------- Status TLV -----------------
 
   void StatusTLV::OutputValue(Buffer& b) const {
